@@ -4,7 +4,7 @@ import contextlib
 from functools import wraps
 
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 
 def suppress(*exceptions):
@@ -17,8 +17,8 @@ def suppress(*exceptions):
     return wrap
 
 
-async def async_suppress(*exceptions):
-    async def wrap(func):
+def async_suppress(*exceptions):
+    def wrap(func):
         @wraps(func)
         async def inner(*args, **kwargs):
             with contextlib.suppress(exceptions):
